@@ -40,6 +40,7 @@ extern char *optarg;
 int64_t minfree = (10 * 1024 *1024), maxfree = 0;
 size_t swapsize = (32 * 1024 * 1024);
 char *swapdir = "/var/tmp";
+int max_inactive_swaps = 5;
 
 typedef struct {
 	char *pathname;
@@ -344,6 +345,8 @@ int swapd_process_config_line(const char *cmd) {
 		minfree = argbuf_int[1];
 	} else if (strcasecmp(argbuf[0], "swapsize") == 0 && argc == 2) {
 		swapsize = argbuf_int[1];
+	} else if (strcasecmp(argbuf[0], "maxunusedswaps") == 0 && argc == 2) {
+		max_inactive_swaps = argbuf_int[1];
 	} else if (strcasecmp(argbuf[0], "swapdir") == 0 && argc == 2) {
 		swapdir = strdup(argbuf[1]);
 	} else {
@@ -395,7 +398,7 @@ int main(int argc, char **argv) {
 	int64_t freemem = -1;
 	char *swapfile = NULL;
 	int ch = -1, i = 0;
-	int active_swaps = 0;
+	int active_swaps = 0, inactive_swaps = 0, dbg_cmp_active_swaps;
 	int swapoffret = -1;
 	int retval = EXIT_SUCCESS;
 
@@ -411,7 +414,7 @@ int main(int argc, char **argv) {
 	swapd_process_config_file(SWAPD_DEF_CONFIG);
 
 	/* Process arguments.. */
-	while ((ch = getopt(argc, argv, "Vhm:s:d:M:o:c:")) != -1) {
+	while ((ch = getopt(argc, argv, "Vhm:s:d:M:o:c:u:")) != -1) {
 		switch (ch) {
 			case 'V':
 				printf("%s version %s\n", PACKAGE_NAME, PACKAGE_VERSION);
@@ -434,11 +437,15 @@ int main(int argc, char **argv) {
 			case 'c':
 				swapd_process_config_file(optarg);
 				break;
+			case 'u':
+				max_inactive_swaps = strtoull(optarg, NULL, 10);
+				break;
 			case ':':
 			case '?':
 				retval = EXIT_FAILURE;
 			case 'h':
 				printf("Usage: swapd [-Vh] [-c config] [-o cmd] [-m min] [-M max] [-s swapsize] [-d dir]\n");
+				printf("             [-u maxunusedswaps]\n");
 				printf("  -V     Print version and exit.\n");
 				printf("  -h     This help.\n");
 				printf("  -c     Process an additional configuration file.\n");
@@ -447,6 +454,8 @@ int main(int argc, char **argv) {
 				printf("  -M     Specify the upper boundary and where to start disabling swap files.\n");
 				printf("  -s     Specify the size of each swap file.\n");
 				printf("  -d     Specify the directory where swapfiles will be created.\n");
+				printf("  -u     Specify the number of unused swaps that can exist before swap files\n");
+				printf("         start being deleted.\n");
 				return(retval);
 				break;
 		}
@@ -466,7 +475,7 @@ int main(int argc, char **argv) {
 	SPOTVAR_LL(minfree);
 
 	while (1) {
-		sleep(5);
+		sleep(10);
 
 		freemem = swapd_get_free_mem();
 		if (freemem == -1) {
@@ -523,9 +532,40 @@ int main(int argc, char **argv) {
 				}
 			}
 
+			/* Delete swap files if there are too many of them. */
+			inactive_swaps = 0;
+			dbg_cmp_active_swaps = 0;
+			for (i = 0; i < (sizeof(swaps) / sizeof(swaps[0])); i++) {
+				if (swaps[i] != NULL) {
+#ifdef DEBUG
+					/* DEBUG */
+					if (swaps[i]->active == 1) {
+						dbg_cmp_active_swaps++;
+					}
+#endif
+					if (swaps[i]->active == 0 && swaps[i]->pathname != NULL) {
+						inactive_swaps++;
+						if (inactive_swaps > max_inactive_swaps) {
+							unlink(swaps[i]->pathname);
+							free(swaps[i]->pathname);
+							free(swaps[i]);
+							swaps[i] = NULL;
+						}
+					}
+				}
+			}
+#ifdef DEBUG
+			if (dbg_cmp_active_swaps != active_swaps) {
+				PRINTERR_D("Error!  Swap count mismatch, chk=%i, var=%i", dbg_cmp_active_swaps, active_swaps);
+			}
+#endif
+
+
 			continue;
 		}
 
+	
+
 	}
 
 	return(EXIT_FAILURE);
